dm: treewide: Rename ofdata_to_platdata() to of_to_plat()

This name is far too long. Rename it to remove the 'data' bits. This makes
it consistent with the platdata->plat rename.

Signed-off-by: Simon Glass <sjg@chromium.org>
diff --git a/drivers/net/fsl_mcdmafec.c b/drivers/net/fsl_mcdmafec.c
index b5610d3..efe8251 100644
--- a/drivers/net/fsl_mcdmafec.c
+++ b/drivers/net/fsl_mcdmafec.c
@@ -491,7 +491,7 @@
 };
 
 /*
  * Boot sequence, called just after mcffec_ofdata_to_platdata,
  * as DM way, it replaces old mcffec_initialize.
  */
 static int mcdmafec_probe(struct udevice *dev)
@@ -565,7 +565,7 @@
 /*
  * Boot sequence, called 1st
  */
-static int mcdmafec_ofdata_to_platdata(struct udevice *dev)
+static int mcdmafec_of_to_plat(struct udevice *dev)
 {
 	struct eth_pdata *pdata = dev_get_plat(dev);
 	const u32 *val;
@@ -590,7 +590,7 @@
 	.name	= "mcdmafec",
 	.id	= UCLASS_ETH,
 	.of_match = mcdmafec_ids,
-	.ofdata_to_platdata = mcdmafec_ofdata_to_platdata,
+	.of_to_plat = mcdmafec_of_to_plat,
 	.probe	= mcdmafec_probe,
 	.remove	= mcdmafec_remove,
 	.ops	= &mcdmafec_ops,
@@ -491,7 +491,7 @@
 
 /*
- * Boot sequence, called just after mcffec_ofdata_to_platdata,
+ * Boot sequence, called just after mcffec_of_to_plat,
  * as DM way, it replaces old mcffec_initialize.
  */